Framing Module
================
Response Frame received from Free-Wili commands

Serial Module API
-----------------
.. automodule:: freewili.framing
   :members:
   :show-inheritance:
   :undoc-members:
